@@ -126,7 +126,7 @@ function(var,month=c(1),infile,outfile){
   mon <- d[dum]
   mon <- as.numeric(mon)
 
- if (length(which(month==mon))>=1){
+ if (sum(!is.na(match(mon,month)))>=1){
 
   target <- array(NA,dim=c(length(lon),length(lat),1))
   time_bnds <- array(NA, dim=c(2,1))
@@ -208,16 +208,16 @@ function(var,month=c(1),infile,outfile){
   
       for (i in 1:length(time1)){
        for (j in 1:length(month)){
-	if (mon[i]==month[j]){
-	  dum_dat <- ncvar_get(id,var,start=c(1,1,i),count=c(-1,-1,1))
-	  dum_dat[is.na(dum_dat)] <- v_missing_value
-	  ncvar_put(ncnew,var1,dum_dat,start=c(1,1,count),count=c(-1,-1,1))
-	  ncvar_put(ncnew,t,time1[i], start=count, count=1)
-	  if ("time_bnds" %in% varnames){
-	    ncvar_put(ncnew,var2,tbnds1[,i],start=c(1,count),count=c(-1,1))
-	  }
-	  count <- count+1
-	}
+	      if (mon[i]==month[j]){
+	        dum_dat <- ncvar_get(id,var,start=c(1,1,i),count=c(-1,-1,1))
+	        dum_dat[is.na(dum_dat)] <- v_missing_value
+	        ncvar_put(ncnew,var1,dum_dat,start=c(1,1,count),count=c(-1,-1,1))
+	        ncvar_put(ncnew,t,time1[i], start=count, count=1)
+	      if ("time_bnds" %in% varnames){
+	        ncvar_put(ncnew,var2,tbnds1[,i],start=c(1,count),count=c(-1,1))
+	      }
+	      count <- count+1
+	      }
        }
       }
       nc_close(id)
