@@ -39,7 +39,7 @@ function(var,infile,outfile){
    v_missing_value = "undefined"
 
    info = "Created with the CM SAF R toolbox." 
-   var_prec="double"
+   var_prec="float"
 
    att_list <- c("standard_name","long_name","units","_FillValue","missing_value","calendar")
    v_att_list <- c("v_standard_name","v_long_name","v_units","v__FillValue","v_missing_value","v_calendar")
@@ -177,7 +177,7 @@ function(var,infile,outfile){
       dum_dat <- array(NA,dim=c(length(lon),length(lat),length(startt)))
       id <- nc_open(infile)
       for (i in 1:length(startt)){
-	dum_dat[,,i] <- ncvar_get(id,var,start=c(1,1,startt[i]),count=c(-1,-1,1),collapse_degen=FALSE)
+	    dum_dat[,,i] <- ncvar_get(id,var,start=c(1,1,startt[i]),count=c(-1,-1,1),collapse_degen=FALSE)
       }
       cat("\r","averaging ",j,sep="")
       mean_data <- rowMeans(dum_dat,dims=2,na.rm=T)
